==> sigutils-2.4.2.tar.gz: sigutils-2.4.2/SigUtils/email.py <==
# -*- coding:utf-8 -*- 
__Autor__ = "Italo Maia"
__Empresa__ = "Sig Informatica Ltda"
__Site__ = "http://www.italomaia.com"
__Versao__ = "1.01"
__DataAlteracao__ = "24/08/2011"

if __name__ == '__main__':
    try:
        if sys.argv[1] == '-9':
            print('email.py\t\t\tVersao:' + __Versao__ + '\tData:'+ __DataAlteracao__) + '\tValidador de Emails'
        else:
            print('\n\nemail.py - Validador de Emails \n'
                   +'Versao: '+ __Versao__ + '\n'
                   +'Data: '+ __DataAlteracao__ + '\n')
    except:
        print('\n\nemail.py - Validador de Emails \n'
               +'Versao: '+ __Versao__ + '\n'
               +'Data: '+ __DataAlteracao__ + '\n')

import re # biblioteca para validação de regex 
 
# caracteres não-alfanuméricos aceitos na parte local 
local_char = r'\!\$\*\+\-\?\^\_\{\|\}\=#/\'~\%&`' 
 
# parte local 
local_word = r'[a-z0-9%(char)s][a-z0-9%(char)s.]{0,62}[a-z0-9%(char)s]?' % {'char':local_char} 
 
domain_label = r'[a-z0-9][a-z0-9\-]{0,61}[a-z0-9]?\.' 
# parte domínio (que deve ser um hostname válido) 
domain_word = r'(%s)+\w{2,4}' % domain_label
 
# o conjunto 
email_regex = '^%s@%s$' % (local_word, domain_word) 
 
# flag CASEINSENSITIVE adicionada 
email_c = re.compile(email_regex, re.I) 
 
def validar_email(word):
    #'Devolve True se o email é válido. False caso contrário.' 
    if email_c.match(word) is not None:
        parts = word.split('@') 
        local_part, domain_part = parts[0], parts[1] 
        if '..' in word or len(word)>256:
            return False 
        if len(local_part) > 64:
           return False
        etiqs = domain_part.split('.')
        for x in etiqs:
           if len(x) > 63:
              return False
        return True 
    return False

==> sigutils-3.1.13.tar.gz: sigutils-3.1.13/SigUtils/email.py <==
# -*- coding:utf-8 -*-

import sys

__Autor__ = "Italo Maia"
__Empresa__ = "Sig Informatica Ltda"
__Site__ = "http://www.italomaia.com"
__Versao__ = "1.01"
__DataAlteracao__ = "24/08/2011"

if __name__ == '__main__':
    try:
        if sys.argv[1] == '-9':
            print(('email.py\t\t\tVersao:' + __Versao__ + '\tData:'+ __DataAlteracao__) +
                  '\tValidador de Emails')
        else:
            print(('\n\nemail.py - Validador de Emails \n' +'Versao: '+ __Versao__ + '\n'
                   + 'Data: '+ __DataAlteracao__ + '\n'))
    except:
        print(('\n\nemail.py - Validador de Emails \n' +'Versao: '+ __Versao__ + '\n' +
               'Data: '+ __DataAlteracao__ + '\n'))

import re # biblioteca para validação de regex 
 
# caracteres não-alfanuméricos aceitos na parte local 
local_char = r'\!\$\*\+\-\?\^\_\{\|\}\=#/\'~\%&`' 
 
# parte local 
local_word = r'[a-z0-9%(char)s][a-z0-9%(char)s.]{0,62}[a-z0-9%(char)s]?' % {'char':local_char} 
 
domain_label = r'[a-z0-9][a-z0-9\-]{0,61}[a-z0-9]?\.' 
# parte domínio (que deve ser um hostname válido) 
domain_word = r'(%s)+\w{2,4}' % domain_label
 
# o conjunto 
email_regex = '^%s@%s$' % (local_word, domain_word) 
 
# flag CASEINSENSITIVE adicionada 
email_c = re.compile(email_regex, re.I) 
 
def validar_email(word):
    #'Devolve True se o email é válido. False caso contrário.' 
    if email_c.match(word) is not None:
        parts = word.split('@') 
        local_part, domain_part = parts[0], parts[1] 
        if '..' in word or len(word)>256:
            return False 
        if len(local_part) > 64:
           return False
        etiqs = domain_part.split('.')
        for x in etiqs:
           if len(x) > 63:
              return False
        return True 
    return False
